@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = "0.05";
+our $VERSION = "0.06";
 
 use Scalar::Util ();
 
@@ -34,32 +34,40 @@ sub set_coerce($) { $_[0]{coerce} = defined $_[1] ? $_[1] : 1; $_[0] }
 
 sub is_same_interface {
     my ($self, $other) = @_;
+
     return unless Scalar::Util::blessed($other) && $other->isa('Sub::Meta::Returns');
 
-    if (defined $self->scalar) {
-        return if !_eq($self->scalar, $other->scalar);
-    }
-    else {
-        return if defined $other->scalar;
-    }
+    return unless defined $self->scalar ? _eq($self->scalar, $other->scalar)
+                                        : !defined $other->scalar;
 
-    if (defined $self->list) {
-        return if !_eq($self->list, $other->list);
-    }
-    else {
-        return if defined $other->list;
-    }
+    return unless defined $self->list ? _eq($self->list, $other->list)
+                                      : !defined $other->list;
 
-    if (defined $self->void) {
-        return if !_eq($self->void, $other->void);
-    }
-    else {
-        return if defined $other->void;
-    }
+    return unless defined $self->void ? _eq($self->void, $other->void)
+                                      : !defined $other->void;
 
     return !!1;
 }
 
+sub is_same_interface_inlined {
+    my ($self, $v) = @_;
+
+    my @src;
+
+    push @src => sprintf("Scalar::Util::blessed(%s) && %s->isa('Sub::Meta::Returns')", $v, $v);
+
+    push @src => defined $self->scalar ? _eq_inlined($self->scalar, sprintf('%s->scalar', $v))
+                                       : sprintf('!defined %s->scalar', $v);
+
+    push @src => defined $self->list ? _eq_inlined($self->list, sprintf('%s->list', $v))
+                                     : sprintf('!defined %s->list', $v);
+
+    push @src => defined $self->void ? _eq_inlined($self->void, sprintf('%s->void', $v))
+                                     : sprintf('!defined %s->void', $v);
+
+    return join "\n && ", @src;
+}
+
 sub _eq {
     my ($type, $other) = @_;
 
@@ -76,6 +84,24 @@ sub _eq {
     return 1;
 }
 
+sub _eq_inlined {
+    my ($type, $v) = @_;
+
+    my @src;
+    if (ref $type && ref $type eq "ARRAY") {
+        push @src => sprintf('ref %s eq "ARRAY"', $v);
+        push @src => sprintf('%d == @{%s}', scalar @$type, $v);
+        for (my $i = 0; $i < @$type; $i++) {
+            push @src => sprintf('"%s" eq %s->[%d]', $type->[$i], $v, $i);
+        }
+    }
+    else {
+        push @src => sprintf('"%s" eq %s', $type, $v);
+    }
+
+    return join "\n && ", @src;
+}
+
 1;
 __END__
 
@@ -107,43 +133,51 @@ Sub::Meta::Returns - meta information about return values
 
 Constructor of C<Sub::Meta::Returns>.
 
-=head2 scalar
+=head2 ACCESSORS
+
+=head3 scalar
 
 A type for value when called in scalar context.
 
-=head2 set_scalar($scalar)
+=head3 set_scalar($scalar)
 
 Setter for C<scalar>.
 
-=head2 list
+=head3 list
 
 A type for value when called in list context.
 
-=head2 set_list($list)
+=head3 set_list($list)
 
 Setter for C<list>.
 
-=head2 void
+=head3 void
 
 A type for value when called in void context.
 
-=head2 set_void($void)
+=head3 set_void($void)
 
 Setter for C<void>.
 
-=head2 coerce
+=head3 coerce
 
 A boolean whether with coercions.
 
-=head2 set_coerce($bool)
+=head3 set_coerce($bool)
 
 Setter for C<coerce>.
 
-=head2 is_same_interface($other_meta)
+=head2 OTHERS
+
+=head3 is_same_interface($other_meta)
 
 A boolean value indicating whether C<Sub::Meta::Returns> object is same or not.
 Specifically, check whether C<scalar>, C<list> and C<void> are equal.
 
+=head3 is_same_interface_inlined($other_meta_inlined)
+
+Returns inlined C<is_same_interface> string.
+
 =head1 LICENSE
 
 Copyright (C) kfly8.
